@@ -19,9 +19,9 @@ func NewWorkingTreeContext(
 	view *gocui.View,
 	getDisplayStrings func(startIdx int, length int) [][]string,
 
-	onFocus func(...types.OnFocusOpts) error,
-	onRenderToMain func(...types.OnFocusOpts) error,
-	onFocusLost func() error,
+	onFocus func(types.OnFocusOpts) error,
+	onRenderToMain func() error,
+	onFocusLost func(opts types.OnFocusLostOpts) error,
 
 	c *types.HelperCommon,
 ) *WorkingTreeContext {
@@ -31,7 +31,7 @@ func NewWorkingTreeContext(
 		FileTreeViewModel: viewModel,
 		ListContextTrait: &ListContextTrait{
 			Context: NewSimpleContext(NewBaseContext(NewBaseContextOpts{
-				ViewName:   "files",
+				View:       view,
 				WindowName: "files",
 				Key:        FILES_CONTEXT_KEY,
 				Kind:       types.SIDE_CONTEXT,
@@ -42,7 +42,6 @@ func NewWorkingTreeContext(
 				OnRenderToMain: onRenderToMain,
 			}),
 			list:              viewModel,
-			viewTrait:         NewViewTrait(view),
 			getDisplayStrings: getDisplayStrings,
 			c:                 c,
 		},
