@@ -8,7 +8,8 @@ func (gui *Gui) reflogCommitsRenderToMain() error {
 	if commit == nil {
 		task = types.NewRenderStringTask("No reflog history")
 	} else {
-		cmdObj := gui.git.Commit.ShowCmdObj(commit.Sha, gui.State.Modes.Filtering.GetPath())
+		cmdObj := gui.git.Commit.ShowCmdObj(commit.Sha, gui.State.Modes.Filtering.GetPath(),
+			gui.IgnoreWhitespaceInDiffView)
 
 		task = types.NewRunPtyTask(cmdObj.GetCmd())
 	}
