@@ -6,6 +6,7 @@ import (
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/gui/keybindings"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
+	"github.com/jesseduffield/lazygit/pkg/tasks"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/spkg/bom"
 )
@@ -15,6 +16,33 @@ func (gui *Gui) resetOrigin(v *gocui.View) error {
 	return v.SetOrigin(0, 0)
 }
 
+// Returns the number of lines that we should read initially from a cmd task so
+// that the scrollbar has the correct size, along with the number of lines after
+// which the view is filled and we can do a first refresh.
+func (gui *Gui) linesToReadFromCmdTask(v *gocui.View) tasks.LinesToRead {
+	_, height := v.Size()
+	_, oy := v.Origin()
+
+	linesForFirstRefresh := height + oy + 10
+
+	// We want to read as many lines initially as necessary to let the
+	// scrollbar go to its minimum height, so that the scrollbar thumb doesn't
+	// change size as you scroll down.
+	minScrollbarHeight := 2
+	linesToReadForAccurateScrollbar := height*(height-1)/minScrollbarHeight + oy
+
+	// However, cap it at some arbitrary max limit, so that we don't get
+	// performance problems for huge monitors or tiny font sizes
+	if linesToReadForAccurateScrollbar > 5000 {
+		linesToReadForAccurateScrollbar = 5000
+	}
+
+	return tasks.LinesToRead{
+		Total:               linesToReadForAccurateScrollbar,
+		InitialRefreshAfter: linesForFirstRefresh,
+	}
+}
+
 func (gui *Gui) cleanString(s string) string {
 	output := string(bom.Clean([]byte(s)))
 	return utils.NormalizeLinefeeds(output)
@@ -50,28 +78,24 @@ func (gui *Gui) resizeCurrentPopupPanel() error {
 		return nil
 	}
 
-	if v == gui.Views.Menu {
+	c := gui.c.CurrentContext()
+
+	if c == gui.State.Contexts.Menu {
 		gui.resizeMenu()
-	} else if v == gui.Views.Confirmation || v == gui.Views.Suggestions {
+	} else if c == gui.State.Contexts.Confirmation || c == gui.State.Contexts.Suggestions {
 		gui.resizeConfirmationPanel()
-	} else if gui.isPopupPanel(v.Name()) {
-		return gui.resizePopupPanel(v, v.Buffer())
+	} else if c == gui.State.Contexts.CommitMessage || c == gui.State.Contexts.CommitDescription {
+		gui.resizeCommitMessagePanels()
 	}
 
 	return nil
 }
 
-func (gui *Gui) resizePopupPanel(v *gocui.View, content string) error {
-	x0, y0, x1, y1 := gui.getConfirmationPanelDimensions(v.Wrap, content)
-	_, err := gui.g.SetView(v.Name(), x0, y0, x1, y1, 0)
-	return err
-}
-
 func (gui *Gui) resizeMenu() {
 	itemCount := gui.State.Contexts.Menu.GetList().Len()
 	offset := 3
 	panelWidth := gui.getConfirmationPanelWidth()
-	x0, y0, x1, y1 := gui.getConfirmationPanelDimensionsForContentHeight(panelWidth, itemCount+offset)
+	x0, y0, x1, y1 := gui.getPopupPanelDimensionsForContentHeight(panelWidth, itemCount+offset)
 	menuBottom := y1 - offset
 	_, _ = gui.g.SetView(gui.Views.Menu.Name(), x0, y0, x1, menuBottom, 0)
 
@@ -93,7 +117,7 @@ func (gui *Gui) resizeConfirmationPanel() {
 		wrap = false
 	}
 	panelHeight := gui.getMessageHeight(wrap, prompt, panelWidth) + suggestionsViewHeight
-	x0, y0, x1, y1 := gui.getConfirmationPanelDimensionsAux(panelWidth, panelHeight)
+	x0, y0, x1, y1 := gui.getPopupPanelDimensionsAux(panelWidth, panelHeight)
 	confirmationViewBottom := y1 - suggestionsViewHeight
 	_, _ = gui.g.SetView(gui.Views.Confirmation.Name(), x0, y0, x1, confirmationViewBottom, 0)
 
@@ -101,15 +125,30 @@ func (gui *Gui) resizeConfirmationPanel() {
 	_, _ = gui.g.SetView(gui.Views.Suggestions.Name(), x0, suggestionsViewTop, x1, suggestionsViewTop+suggestionsViewHeight, 0)
 }
 
+func (gui *Gui) resizeCommitMessagePanels() {
+	panelWidth := gui.getConfirmationPanelWidth()
+	content := gui.Views.CommitDescription.TextArea.GetContent()
+	summaryViewHeight := 3
+	panelHeight := gui.getMessageHeight(false, content, panelWidth)
+	minHeight := 7
+	if panelHeight < minHeight {
+		panelHeight = minHeight
+	}
+	x0, y0, x1, y1 := gui.getPopupPanelDimensionsAux(panelWidth, panelHeight)
+
+	_, _ = gui.g.SetView(gui.Views.CommitMessage.Name(), x0, y0, x1, y0+summaryViewHeight-1, 0)
+	_, _ = gui.g.SetView(gui.Views.CommitDescription.Name(), x0, y0+summaryViewHeight, x1, y1+summaryViewHeight, 0)
+}
+
 func (gui *Gui) globalOptionsMap() map[string]string {
 	keybindingConfig := gui.c.UserConfig.Keybinding
 
 	return map[string]string{
 		fmt.Sprintf("%s/%s", keybindings.Label(keybindingConfig.Universal.ScrollUpMain), keybindings.Label(keybindingConfig.Universal.ScrollDownMain)):                                                                                                               gui.c.Tr.LcScroll,
 		fmt.Sprintf("%s %s %s %s", keybindings.Label(keybindingConfig.Universal.PrevBlock), keybindings.Label(keybindingConfig.Universal.NextBlock), keybindings.Label(keybindingConfig.Universal.PrevItem), keybindings.Label(keybindingConfig.Universal.NextItem)): gui.c.Tr.LcNavigate,
-		keybindings.Label(keybindingConfig.Universal.Return):     gui.c.Tr.LcCancel,
-		keybindings.Label(keybindingConfig.Universal.Quit):       gui.c.Tr.LcQuit,
-		keybindings.Label(keybindingConfig.Universal.OptionMenu): gui.c.Tr.LcMenu,
+		keybindings.Label(keybindingConfig.Universal.Return):         gui.c.Tr.LcCancel,
+		keybindings.Label(keybindingConfig.Universal.Quit):           gui.c.Tr.LcQuit,
+		keybindings.Label(keybindingConfig.Universal.OptionMenuAlt1): gui.c.Tr.LcMenu,
 		fmt.Sprintf("%s-%s", keybindings.Label(keybindingConfig.Universal.JumpToBlock[0]), keybindings.Label(keybindingConfig.Universal.JumpToBlock[len(keybindingConfig.Universal.JumpToBlock)-1])): gui.c.Tr.LcJump,
 		fmt.Sprintf("%s/%s", keybindings.Label(keybindingConfig.Universal.ScrollLeft), keybindings.Label(keybindingConfig.Universal.ScrollRight)):                                                    gui.c.Tr.LcScrollLeftRight,
 	}
