@@ -13,7 +13,7 @@ func dutchTranslationSet() TranslationSet {
 		MainTitle:                           "Hoofd",
 		StagingTitle:                        "Staging",
 		NormalTitle:                         "Normaal",
-		CommitMessage:                       "Commitbericht",
+		CommitSummary:                       "Commitbericht",
 		CredentialsUsername:                 "Gebruikersnaam",
 		CredentialsPassword:                 "Wachtwoord",
 		CredentialsPassphrase:               "Voer een wachtwoordzin in voor de SSH-sleutel",
@@ -60,14 +60,14 @@ func dutchTranslationSet() TranslationSet {
 		LcNewBranch:                         "nieuwe branch",
 		LcDeleteBranch:                      "verwijder branch",
 		NoBranchesThisRepo:                  "Geen branches voor deze repo",
-		CommitMessageConfirm:                "{{.keyBindClose}}: Sluiten, {{.keyBindNewLine}}: Nieuwe lijn, {{.keyBindConfirm}}: Bevestig",
+		CommitMessageConfirm:                "{{.keyBindClose}}: Sluiten, {{.keyBindConfirm}}: Bevestig",
 		CommitWithoutMessageErr:             "Je kan geen commit maken zonder commit bericht",
 		CloseConfirm:                        "{{.keyBindClose}}: Sluiten, {{.keyBindConfirm}}: Bevestig",
 		LcClose:                             "sluiten",
 		LcQuit:                              "quit",
 		LcSquashDown:                        "squash beneden",
 		LcFixupCommit:                       "Fixup commit",
-		YouNoCommitsToSquash:                "Je hebt geen commits om mee te squashen",
+		CannotSquashOrFixupFirstCommit:      "There's no commit below to squash into",
 		Fixup:                               "Fixup",
 		SureFixupThisCommit:                 "Weet je zeker dat je fixup wil uitvoeren op deze commit? De commit hieronder zol worden squashed in deze",
 		SureSquashThisCommit:                "Weet je zeker dat je deze commit wil samenvoegen met de commit hieronder?",
@@ -166,9 +166,7 @@ func dutchTranslationSet() TranslationSet {
 		ReflogCommitsTitle:                  "Reflog",
 		GlobalTitle:                         "Globale Sneltoetsen",
 		ConflictsResolved:                   "alle merge conflicten zijn opgelost. Wilt je verder gaan?",
-		RebasingTitle:                       "Rebasen",
 		MergingTitle:                        "Mergen",
-		ConfirmRebase:                       "Weet je zeker dat je '{{.checkedOutBranch}}' op '{{.selectedBranch}}' wil rebasen?",
 		ConfirmMerge:                        "Weet je zeker dat je '{{.selectedBranch}}' in '{{.checkedOutBranch}}' wil mergen?",
 		FwdNoUpstream:                       "Kan niet de branch vooruitspoelen zonder upstream",
 		FwdCommitsToPush:                    "Je kan niet vooruitspoelen als de branch geen nieuwe commits heeft",
@@ -181,8 +179,6 @@ func dutchTranslationSet() TranslationSet {
 		LcPasteCommits:                      "plak commits (cherry-pick)",
 		SureCherryPick:                      "Weet je zeker dat je de gekopieerde commits naar deze branch wil cherry-picken?",
 		CherryPick:                          "Cherry-Pick",
-		CannotRebaseOntoFirstCommit:         "Je kan niet interactief rebasen naar de eerste commit",
-		CannotSquashOntoSecondCommit:        "Je kan niet een squash/fixup doen naar de 2de commit",
 		Donate:                              "Doneer",
 		PrevLine:                            "selecteer de vorige lijn",
 		NextLine:                            "selecteer de volgende lijn",
