@@ -34,7 +34,7 @@ func japaneseTranslationSet() TranslationSet {
 		MergingTitle:            "メインパネル (Merging)",
 		NormalTitle:             "メインパネル (Normal)",
 		LogTitle:                "ログ",
-		CommitMessage:           "コミットメッセージ",
+		CommitSummary:           "コミットメッセージ",
 		CredentialsUsername:     "ユーザ名",
 		CredentialsPassword:     "パスワード",
 		CredentialsPassphrase:   "SSH鍵のパスフレーズを入力",
@@ -85,7 +85,7 @@ func japaneseTranslationSet() TranslationSet {
 		LcNewBranch:             "新しいブランチを作成",
 		LcDeleteBranch:          "ブランチを削除",
 		NoBranchesThisRepo:      "リポジトリにブランチが存在しません",
-		CommitMessageConfirm:    "{{.keyBindClose}}: 閉じる, {{.keyBindNewLine}}: 改行, {{.keyBindConfirm}}: 確定",
+		CommitMessageConfirm:    "{{.keyBindClose}}: 閉じる, {{.keyBindConfirm}}: 確定",
 		CommitWithoutMessageErr: "コミットメッセージを入力してください",
 		CloseConfirm:            "{{.keyBindClose}}: 閉じる/キャンセル, {{.keyBindConfirm}}: 確認",
 		LcClose:                 "閉じる",
@@ -93,7 +93,7 @@ func japaneseTranslationSet() TranslationSet {
 		// LcSquashDown:                        "squash down",
 		// LcFixupCommit:                       "fixup commit",
 		// NoCommitsThisBranch:                 "No commits for this branch",
-		// YouNoCommitsToSquash:                "You have no commits to squash with",
+		// CannotSquashOrFixupFirstCommit:      "There's no commit below to squash into",
 		// Fixup:                               "Fixup",
 		// SureFixupThisCommit:                 "Are you sure you want to 'fixup' this commit? It will be merged into the commit below",
 		// SureSquashThisCommit:                "Are you sure you want to squash this commit into the commit below?",
@@ -215,9 +215,7 @@ func japaneseTranslationSet() TranslationSet {
 		LcCherryPickCopyRange: "コミットを範囲コピー (cherry-pick)",
 		LcPasteCommits:        "コミットを貼り付け (cherry-pick)",
 		// SureCherryPick:                      "Are you sure you want to cherry-pick the copied commits onto this branch?",
-		CherryPick: "Cherry-Pick",
-		// CannotRebaseOntoFirstCommit:         "You cannot interactive rebase onto the first commit",
-		// CannotSquashOntoSecondCommit:        "You cannot squash/fixup onto the second commit",
+		CherryPick:            "Cherry-Pick",
 		Donate:                "支援",
 		AskQuestion:           "質問",
 		PrevLine:              "前の行を選択",
@@ -405,7 +403,7 @@ func japaneseTranslationSet() TranslationSet {
 		LcCreateNewBranchFromCommit:  "コミットにブランチを作成",
 		LcBuildingPatch:              "パッチを構築",
 		LcViewCommits:                "コミットを閲覧",
-		MinGitVersionError:           "lazygitの実行にはGit 2.0以降のバージョンが必要です。Gitを更新してください。もしくは、lazygitの後方互換性を改善するために https://github.com/jesseduffield/lazygit/issues にissueを作成してください。",
+		MinGitVersionError:           "lazygitの実行にはGit 2.20以降のバージョンが必要です。Gitを更新してください。もしくは、lazygitの後方互換性を改善するために https://github.com/jesseduffield/lazygit/issues にissueを作成してください。",
 		LcRunningCustomCommandStatus: "カスタムコマンドを実行",
 		// LcSubmoduleStashAndReset:            "stash uncommitted submodule changes and update",
 		// LcAndResetSubmodules:                "and reset submodules",
