@@ -33,7 +33,7 @@ func koreanTranslationSet() TranslationSet {
 		MergingTitle:                        "메인 패널 (Merging)",
 		NormalTitle:                         "메인 패널 (Normal)",
 		LogTitle:                            "로그",
-		CommitMessage:                       "커밋 메시지",
+		CommitSummary:                       "커밋 메시지",
 		CredentialsUsername:                 "사용자 이름",
 		CredentialsPassword:                 "패스워드",
 		CredentialsPassphrase:               "SSH키의 passphrase 입력",
@@ -84,7 +84,7 @@ func koreanTranslationSet() TranslationSet {
 		LcNewBranch:                         "새 브랜치 생성",
 		LcDeleteBranch:                      "브랜치 삭제",
 		NoBranchesThisRepo:                  "저장소에 브랜치가 존재하지 않습니다.",
-		CommitMessageConfirm:                "{{.keyBindClose}}: 닫기, {{.keyBindNewLine}}: 개행, {{.keyBindConfirm}}: 확인",
+		CommitMessageConfirm:                "{{.keyBindClose}}: 닫기, {{.keyBindConfirm}}: 확인",
 		CommitWithoutMessageErr:             "커밋 메시지를 입력하세요.",
 		CloseConfirm:                        "{{.keyBindClose}}: 닫기/취소, {{.keyBindConfirm}}: 확인",
 		LcClose:                             "닫기",
@@ -92,7 +92,7 @@ func koreanTranslationSet() TranslationSet {
 		LcSquashDown:                        "squash down",
 		LcFixupCommit:                       "fixup commit",
 		NoCommitsThisBranch:                 "이 브랜치에 커밋이 없습니다.",
-		YouNoCommitsToSquash:                "You have no commits to squash with",
+		CannotSquashOrFixupFirstCommit:      "There's no commit below to squash into",
 		Fixup:                               "Fixup",
 		SureFixupThisCommit:                 "Are you sure you want to 'fixup' this commit? It will be merged into the commit below",
 		SureSquashThisCommit:                "Are you sure you want to squash this commit into the commit below?",
@@ -202,8 +202,6 @@ func koreanTranslationSet() TranslationSet {
 		ReflogCommitsTitle:                  "Reflog",
 		GlobalTitle:                         "글로벌 키 바인딩",
 		ConflictsResolved:                   "모든 병합 충돌이 해결되었습니다. 계속 할까요?",
-		RebasingTitle:                       "리베이스 중",
-		ConfirmRebase:                       "정말로 '{{.checkedOutBranch}}' 을(를) '{{.selectedBranch}}'에 리베이스 하시겠습니까?",
 		ConfirmMerge:                        "정말로 '{{.selectedBranch}}' 을(를) '{{.checkedOutBranch}}'에 병합하시겠습니까?",
 		FwdNoUpstream:                       "Cannot fast-forward a branch with no upstream",
 		FwdNoLocalUpstream:                  "Cannot fast-forward a branch whose remote is not registered locally",
@@ -217,8 +215,6 @@ func koreanTranslationSet() TranslationSet {
 		LcPasteCommits:                      "커밋을 붙여넣기 (cherry-pick)",
 		SureCherryPick:                      "정말로 복사한 커밋을 이 브랜치에 체리픽하시겠습니까?",
 		CherryPick:                          "체리픽",
-		CannotRebaseOntoFirstCommit:         "첫 번째 커밋에 대해 대화식으로 리베이스할 수 없습니다.",
-		CannotSquashOntoSecondCommit:        "두 번째 커밋을 squash/fixup할 수 없습니다.",
 		Donate:                              "후원",
 		AskQuestion:                         "질문하기",
 		PrevLine:                            "이전 줄 선택",
@@ -406,7 +402,7 @@ func koreanTranslationSet() TranslationSet {
 		LcCreateNewBranchFromCommit:         "커밋에서 새 브랜치를 만듭니다.",
 		LcBuildingPatch:                     "building patch",
 		LcViewCommits:                       "커밋 보기",
-		MinGitVersionError:                  "lazygit 실행을 위해서는 Git 2.0 이후의 버전(2014년 이후의)이 필요합니다. Git를 업데이트 해주세요. 아니면 lazygit이 이전 버전과 더 잘 호환되도록 https://github.com/jesseduffield/lazygit/issues 에 issue를 작성해 주세요.",
+		MinGitVersionError:                  "lazygit 실행을 위해서는 Git 2.20 이후의 버전(2018년 이후의)이 필요합니다. Git를 업데이트 해주세요. 아니면 lazygit이 이전 버전과 더 잘 호환되도록 https://github.com/jesseduffield/lazygit/issues 에 issue를 작성해 주세요.",
 		LcRunningCustomCommandStatus:        "커스텀 명령어 실행",
 		LcSubmoduleStashAndReset:            "stash uncommitted submodule changes and update",
 		LcAndResetSubmodules:                "and reset submodules",
