@@ -10,7 +10,7 @@ func polishTranslationSet() TranslationSet {
 		StashTitle:                          "Schowek",
 		UnstagedChanges:                     "Zmiany poza poczekalnią",
 		StagedChanges:                       "Zmiany w poczekalni",
-		CommitMessage:                       "Komunikat commita",
+		CommitSummary:                       "Komunikat commita",
 		CredentialsUsername:                 "Użytkownik",
 		CredentialsPassword:                 "Hasło",
 		CredentialsPassphrase:               "Fraza",
@@ -55,14 +55,14 @@ func polishTranslationSet() TranslationSet {
 		LcNewBranch:                         "nowa gałąź",
 		LcDeleteBranch:                      "usuń gałąź",
 		NoBranchesThisRepo:                  "Brak gałęzi dla tego repozytorium",
-		CommitMessageConfirm:                "{{.keyBindClose}}: zamknij, {{.keyBindNewLine}}: nowa linia, {{.keyBindConfirm}}: potwierdź",
+		CommitMessageConfirm:                "{{.keyBindClose}}: zamknij, {{.keyBindConfirm}}: potwierdź",
 		CommitWithoutMessageErr:             "Nie możesz commitować bez komunikatu",
 		CloseConfirm:                        "{{.keyBindClose}}: zamknij, {{.keyBindConfirm}}: potwierdź",
 		LcClose:                             "zamknij",
 		LcSquashDown:                        "ściśnij",
 		LcFixupCommit:                       "napraw commit",
 		NoCommitsThisBranch:                 "Brak commitów dla tej gałęzi",
-		YouNoCommitsToSquash:                "Nie masz commitów do spłaszczenia",
+		CannotSquashOrFixupFirstCommit:      "There's no commit below to squash into",
 		Fixup:                               "Napraw",
 		SureFixupThisCommit:                 "Jesteś pewny, ze chcesz naprawić ten commit? Commit poniżej zostanie spłaszczony w górę wraz z tym",
 		LcRewordCommit:                      "zmień nazwę commita",
@@ -112,9 +112,7 @@ func polishTranslationSet() TranslationSet {
 		FileStagingRequirements:             "Można tylko zatwierdzić pojedyncze linie dla śledzonych plików z niezatwierdzonymi zmianami",
 		StagingTitle:                        "Poczekalnia",
 		ReturnToFilesPanel:                  "wróć do panelu plików",
-		RebasingTitle:                       "Zmiana bazy",
 		MergingTitle:                        "Scalanie",
-		ConfirmRebase:                       "Czy napewno chcesz zmienić bazę '{{.checkedOutBranch}}' na '{{.selectedBranch}}'?",
 		ConfirmMerge:                        "Czy na pewno chcesz scalić '{{.selectedBranch}}' do '{{.checkedOutBranch}}'?",
 		FwdNoUpstream:                       "Nie można przewinąć gałęzi bez gałęzi nadrzędnej",
 		FwdCommitsToPush:                    "Nie można przewinąć gałęzi z commitami do wysłania",
@@ -149,8 +147,6 @@ func polishTranslationSet() TranslationSet {
 		LcPasteCommits:                      "wklej commity (przebieranie)",
 		SureCherryPick:                      "Czy na pewno chcesz przebierać w skopiowanych commitach na tej gałęzi?",
 		CherryPick:                          "Przebieranie",
-		CannotRebaseOntoFirstCommit:         "Nie można interaktywnie zmienić bazy na pierwszym commicie",
-		CannotSquashOntoSecondCommit:        "Nie można spłaszczyć na drugi commit",
 		Donate:                              "Wesprzyj",
 		PrevLine:                            "poprzednia linia",
 		NextLine:                            "następna linia",
