@@ -38,6 +38,15 @@ func (self *Shell) RunCommand(cmdStr string) *Shell {
 	return self
 }
 
+// Help files are located at test/files from the root the lazygit repo.
+// E.g. You may want to create a pre-commit hook file there, then call this
+// function to copy it into your test repo.
+func (self *Shell) CopyHelpFile(source string, destination string) *Shell {
+	self.RunCommand(fmt.Sprintf("cp ../../../../../files/%s %s", source, destination))
+
+	return self
+}
+
 func (self *Shell) runCommandWithOutput(cmdStr string) (string, error) {
 	args := str.ToArgv(cmdStr)
 	cmd := secureexec.Command(args[0], args[1:]...)
@@ -85,6 +94,16 @@ func (self *Shell) CreateFile(path string, content string) *Shell {
 	return self
 }
 
+func (self *Shell) DeleteFile(path string) *Shell {
+	fullPath := filepath.Join(self.dir, path)
+	err := os.Remove(fullPath)
+	if err != nil {
+		self.fail(fmt.Sprintf("error deleting file: %s\n%s", fullPath, err))
+	}
+
+	return self
+}
+
 func (self *Shell) CreateDir(path string) *Shell {
 	fullPath := filepath.Join(self.dir, path)
 	if err := os.MkdirAll(fullPath, 0o755); err != nil {
@@ -116,6 +135,10 @@ func (self *Shell) Merge(name string) *Shell {
 	return self.RunCommand("git merge --commit --no-ff " + name)
 }
 
+func (self *Shell) ContinueMerge() *Shell {
+	return self.RunCommand("git -c core.editor=true merge --continue")
+}
+
 func (self *Shell) GitAdd(path string) *Shell {
 	return self.RunCommand(fmt.Sprintf("git add \"%s\"", path))
 }
@@ -132,6 +155,18 @@ func (self *Shell) EmptyCommit(message string) *Shell {
 	return self.RunCommand(fmt.Sprintf("git commit --allow-empty -m \"%s\"", message))
 }
 
+func (self *Shell) Revert(ref string) *Shell {
+	return self.RunCommand(fmt.Sprintf("git revert %s", ref))
+}
+
+func (self *Shell) CreateLightweightTag(name string, ref string) *Shell {
+	return self.RunCommand(fmt.Sprintf("git tag %s %s", name, ref))
+}
+
+func (self *Shell) CreateAnnotatedTag(name string, message string, ref string) *Shell {
+	return self.RunCommand(fmt.Sprintf("git tag -a %s -m \"%s\" %s", name, message, ref))
+}
+
 // convenience method for creating a file and adding it
 func (self *Shell) CreateFileAndAdd(fileName string, fileContents string) *Shell {
 	return self.
@@ -146,11 +181,22 @@ func (self *Shell) UpdateFileAndAdd(fileName string, fileContents string) *Shell
 		GitAdd(fileName)
 }
 
+// convenience method for deleting a file and adding it
+func (self *Shell) DeleteFileAndAdd(fileName string) *Shell {
+	return self.
+		DeleteFile(fileName).
+		GitAdd(fileName)
+}
+
 // creates commits 01, 02, 03, ..., n with a new file in each
 // The reason for padding with zeroes is so that it's easier to do string
 // matches on the commit messages when there are many of them
 func (self *Shell) CreateNCommits(n int) *Shell {
-	for i := 1; i <= n; i++ {
+	return self.CreateNCommitsStartingAt(n, 1)
+}
+
+func (self *Shell) CreateNCommitsStartingAt(n, startIndex int) *Shell {
+	for i := startIndex; i < startIndex+n; i++ {
 		self.CreateFileAndAdd(
 			fmt.Sprintf("file%02d.txt", i),
 			fmt.Sprintf("file%02d content", i),
@@ -167,20 +213,34 @@ func (self *Shell) StashWithMessage(message string) *Shell {
 }
 
 func (self *Shell) SetConfig(key string, value string) *Shell {
-	self.RunCommand(fmt.Sprintf(`git config --local "%s" %s`, key, value))
+	self.RunCommand(fmt.Sprintf(`git config --local "%s" "%s"`, key, value))
 	return self
 }
 
 // creates a clone of the repo in a sibling directory and adds the clone
 // as a remote, then fetches it.
 func (self *Shell) CloneIntoRemote(name string) *Shell {
-	self.RunCommand(fmt.Sprintf("git clone --bare . ../%s", name))
+	self.Clone(name)
 	self.RunCommand(fmt.Sprintf("git remote add %s ../%s", name, name))
 	self.RunCommand(fmt.Sprintf("git fetch %s", name))
 
 	return self
 }
 
+func (self *Shell) CloneIntoSubmodule(submoduleName string) *Shell {
+	self.Clone("other_repo")
+	self.RunCommand(fmt.Sprintf("git submodule add ../other_repo %s", submoduleName))
+
+	return self
+}
+
+// clones repo into a sibling directory
+func (self *Shell) Clone(repoName string) *Shell {
+	self.RunCommand(fmt.Sprintf("git clone --bare . ../%s", repoName))
+
+	return self
+}
+
 // e.g. branch: 'master', upstream: 'origin/master'
 func (self *Shell) SetBranchUpstream(branch string, upstream string) *Shell {
 	self.RunCommand(fmt.Sprintf("git branch --set-upstream-to=%s %s", upstream, branch))
@@ -199,3 +259,9 @@ func (self *Shell) HardReset(ref string) *Shell {
 
 	return self
 }
+
+func (self *Shell) Stash(message string) *Shell {
+	self.RunCommand(fmt.Sprintf("git stash -m \"%s\"", message))
+
+	return self
+}
