@@ -36,17 +36,14 @@ var RebaseAndDrop = NewIntegrationTest(NewIntegrationTestArgs{
 			SelectNextItem().
 			Press(keys.Branches.RebaseBranch)
 
-		t.ExpectPopup().Confirmation().
-			Title(Equals("Rebasing")).
-			Content(Contains("Are you sure you want to rebase 'first-change-branch' on top of 'second-change-branch'?")).
+		t.ExpectPopup().Menu().
+			Title(Equals("Rebase 'first-change-branch' onto 'second-change-branch'")).
+			Select(Contains("simple rebase")).
 			Confirm()
 
 		t.Views().Information().Content(Contains("rebasing"))
 
-		t.ExpectPopup().Confirmation().
-			Title(Equals("Auto-merge failed")).
-			Content(Contains("Conflicts!")).
-			Confirm()
+		t.Common().AcknowledgeConflicts()
 
 		t.Views().Files().IsFocused().
 			SelectedLine(MatchesRegexp("UU.*file"))
@@ -78,10 +75,7 @@ var RebaseAndDrop = NewIntegrationTest(NewIntegrationTestArgs{
 			IsFocused().
 			PressPrimaryAction()
 
-		t.ExpectPopup().Confirmation().
-			Title(Equals("continue")).
-			Content(Contains("all merge conflicts resolved. Continue?")).
-			Confirm()
+		t.Common().ContinueOnConflictsResolved()
 
 		t.Views().Information().Content(DoesNotContain("rebasing"))
 
