@@ -6,42 +6,6 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-// TestIncludesString is a function.
-func TestIncludesString(t *testing.T) {
-	type scenario struct {
-		list     []string
-		element  string
-		expected bool
-	}
-
-	scenarios := []scenario{
-		{
-			[]string{"a", "b"},
-			"a",
-			true,
-		},
-		{
-			[]string{"a", "b"},
-			"c",
-			false,
-		},
-		{
-			[]string{"a", "b"},
-			"",
-			false,
-		},
-		{
-			[]string{""},
-			"",
-			true,
-		},
-	}
-
-	for _, s := range scenarios {
-		assert.EqualValues(t, s.expected, IncludesString(s.list, s.element))
-	}
-}
-
 func TestNextIndex(t *testing.T) {
 	type scenario struct {
 		testName string
@@ -169,26 +133,6 @@ func TestEscapeSpecialChars(t *testing.T) {
 	}
 }
 
-func TestUniq(t *testing.T) {
-	for _, test := range []struct {
-		values []string
-		want   []string
-	}{
-		{
-			values: []string{"a", "b", "c"},
-			want:   []string{"a", "b", "c"},
-		},
-		{
-			values: []string{"a", "b", "a", "b", "c"},
-			want:   []string{"a", "b", "c"},
-		},
-	} {
-		if got := Uniq(test.values); !assert.EqualValues(t, got, test.want) {
-			t.Errorf("Uniq(%v) = %v; want %v", test.values, got, test.want)
-		}
-	}
-}
-
 func TestLimit(t *testing.T) {
 	for _, test := range []struct {
 		values []string
@@ -232,26 +176,6 @@ func TestLimit(t *testing.T) {
 	}
 }
 
-func TestReverse(t *testing.T) {
-	for _, test := range []struct {
-		values []string
-		want   []string
-	}{
-		{
-			values: []string{"a", "b", "c"},
-			want:   []string{"c", "b", "a"},
-		},
-		{
-			values: []string{},
-			want:   []string{},
-		},
-	} {
-		if got := Reverse(test.values); !assert.EqualValues(t, got, test.want) {
-			t.Errorf("Reverse(%v) = %v; want %v", test.values, got, test.want)
-		}
-	}
-}
-
 func TestLimitStr(t *testing.T) {
 	for _, test := range []struct {
 		values string
@@ -309,3 +233,85 @@ func TestLimitStr(t *testing.T) {
 		}
 	}
 }
+
+func TestMoveElement(t *testing.T) {
+	type scenario struct {
+		testName string
+		list     []int
+		from     int
+		to       int
+		expected []int
+	}
+
+	scenarios := []scenario{
+		{
+			"no elements",
+			[]int{},
+			0,
+			0,
+			[]int{},
+		},
+		{
+			"one element",
+			[]int{1},
+			0,
+			0,
+			[]int{1},
+		},
+		{
+			"two elements, moving first to second",
+			[]int{1, 2},
+			0,
+			1,
+			[]int{2, 1},
+		},
+		{
+			"two elements, moving second to first",
+			[]int{1, 2},
+			1,
+			0,
+			[]int{2, 1},
+		},
+		{
+			"three elements, moving first to second",
+			[]int{1, 2, 3},
+			0,
+			1,
+			[]int{2, 1, 3},
+		},
+		{
+			"three elements, moving second to first",
+			[]int{1, 2, 3},
+			1,
+			0,
+			[]int{2, 1, 3},
+		},
+		{
+			"three elements, moving second to third",
+			[]int{1, 2, 3},
+			1,
+			2,
+			[]int{1, 3, 2},
+		},
+		{
+			"three elements, moving third to second",
+			[]int{1, 2, 3},
+			2,
+			1,
+			[]int{1, 3, 2},
+		},
+	}
+
+	for _, s := range scenarios {
+		s := s
+		t.Run(s.testName, func(t *testing.T) {
+			assert.EqualValues(t, s.expected, MoveElement(s.list, s.from, s.to))
+		})
+	}
+
+	t.Run("from out of bounds", func(t *testing.T) {
+		assert.Panics(t, func() {
+			MoveElement([]int{1, 2, 3}, 3, 0)
+		})
+	})
+}
